@@ -46,7 +46,7 @@ class Miniserver:
 
     def connect(self, loop, connection_status):
         """Connect to the miniserver."""
-        _LOGGER.debug("connect v0.0.48")
+        _LOGGER.debug("connect v0.0.49")
         from .wsclient import WSClient
         self.loop = loop
         self.async_connection_status_callback = connection_status
@@ -171,6 +171,17 @@ class Miniserver:
 
     def encrypt_command(self, command):
         _LOGGER.debug('encrypt_command()')
+        #_new_aes = AES.new(self._key, AES.MODE_CBC, self._iv)
+        #aes_cipher = self.get_new_aes_chiper()
+        #encrypted = aes_cipher.encrypt(s)
+        #encoded = b64encode(encrypted)
+        #encoded_url = req.pathname2url(encoded.decode("utf-8"))
+
+
+
+
+
+
         salted_command = "salt/{0}/{1}".format(self.client_salt, command) 
         _LOGGER.debug("  salted_command: {0}".format(salted_command))
 
@@ -187,7 +198,7 @@ class Miniserver:
         #_LOGGER.debug("  padding: {0} {1}".format(type(padding), padding))
         padded_salted_command = salted_command + padding
 
-        enc_cmd_part = cipher_aes.encrypt(pad(salted_command.encode('utf8'), AES.block_size))
+        #enc_cmd_part = cipher_aes.encrypt(pad(salted_command.encode('utf8'), AES.block_size))
         enc_cmd_part = cipher_aes.encrypt(bytes(padded_salted_command, 'utf-8'))
         #_LOGGER.debug("  enc_cmd_part: {0} {1}".format(type(enc_cmd_part), enc_cmd_part))
 
